<?php

/**
 * CombinaryItemsController.php file.
 */

namespace Drupal\combinary\Controller;

use Drupal\Core\Controller\ControllerBase;
use \Symfony\Component\HttpFoundation\Response;
use Drupal\Core\Config\ConfigFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\combinary\CombinaryManager;

/**
 * CombinaryItemsController - custom controller created for use with AJAX call.
 */
class CombinaryItemsController extends ControllerBase {

  protected $configFactory;
  protected $manager;

  /**
   * CombinaryItemsController constructor.
   */
  public function __construct(ConfigFactoryInterface $config_factory, CombinaryManager $combinary_manager) {
    $this->configFactory = $config_factory;
    $this->manager = $combinary_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('combinary')
    );
  }

  /**
   * Render posts into template.
   */
  public function render($limit, $offset) {

    $config = $this->configFactory->get('combinary.combinarysettings');
    $posts = $this->manager->getCombinaryJson($limit, $offset);

    $build = [
      '#theme' => 'combinary_list_theme_hook',
      '#entries' => $posts,
      '#settings' => [
        'striptags' => $config->get('combinary_striptags'),
        'combinary_limit_post_characters' => $config->get('combinary_limit_post_characters'),
      ],
    ];

    return new Response(render($build));

  }

}
