<?php

/**
 * CombinarySettingsForm.php file.
 */

namespace Drupal\combinary\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class CombinarySettingsForm.
 */
class CombinarySettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'combinary.combinarysettings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'combinary_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('combinary.combinarysettings');
    $form['combinary_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Combinary JSON file URL'),
      '#description' => $this->t('Enter your Combinary JSON file URL'),
      '#default_value' => $config->get('combinary_url'),
    ];
    $form['combinary_items_limit'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Items limit'),
      '#description' => $this->t('Max number of items loaded'),
      '#default_value' => $config->get('combinary_items_limit'),
    ];
    $form['combinary_load_more_posts'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Load more'),
      '#description' => $this->t('Load more - number of posts per load'),
      '#default_value' => $config->get('combinary_load_more_posts') ? $config->get('combinary_load_more_posts') : 10,
    ];
    $form['combinary_striptags'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Strip html tags'),
      '#description' => $this->t('Strip html tags'),
      '#default_value' => $config->get('combinary_striptags'),
    ];
    $form['combinary_limit_post_characters'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Limit characters'),
      '#description' => $this->t('Limit post characters'),
      '#default_value' => $config->get('combinary_limit_post_characters'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('combinary.combinarysettings')
      ->set('combinary_url', $form_state->getValue('combinary_url'))
      ->set('combinary_items_limit', $form_state->getValue('combinary_items_limit'))
      ->set('combinary_load_more_posts', $form_state->getValue('combinary_load_more_posts'))
      ->set('combinary_striptags', $form_state->getValue('combinary_striptags'))
      ->set('combinary_limit_post_characters', $form_state->getValue('combinary_limit_post_characters'))
      ->save();
  }

}
