<?php

/**
 * CombinaryBlock.php file.
 */

namespace Drupal\combinary\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\combinary\CombinaryManager;

/**
 * Provides a 'combinary' Block.
 *
 * @Block(
 * id = "block_combinary",
 * admin_label = @Translation("Combinary"),
 * )
 */
class CombinaryBlock extends BlockBase implements ContainerFactoryPluginInterface {

  protected $configFactory;
  protected $manager;

  /**
   * CombinaryBlock constructor.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ConfigFactory $config_factory, CombinaryManager $combinary_manager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->configFactory = $config_factory;
    $this->manager = $combinary_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('config.factory'),
      $container->get('combinary')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {

    $config = $this->configFactory->get('combinary.combinarysettings');

    $posts = $this->manager->getCombinaryJson($config->get('combinary_items_limit'),0);

    $entries = [];
    $snetworks = [];

    foreach ($posts as $post) {
      $entries[] = $post;
      $snetworks[$post['itemType']] = $post['itemType'];
    }

    return [
      '#theme' => 'combinaryblock-block',
      '#entries' => $entries,
      '#snetworks' => $snetworks,
      '#content' => $content,
      '#settings' => [
        'striptags' => $config->get('combinary_striptags'),
        'combinary_limit_post_characters' => $config->get('combinary_limit_post_characters')
      ]
    ];
  }
}
